@@ -1,38 +1,58 @@
-
+using Test
+using Test: detect_ambiguities
+using EllipsisNotation
+using StaticArrayInterface: StaticArrayInterface
 @test isempty(detect_ambiguities(EllipsisNotation))
 
 A = Array{Int}(undef, 2, 4, 2)
 
-A[.., 1] = [2 1 4 5
-    2 2 3 6]
+A[.., 1] = [
+    2 1 4 5
+    2 2 3 6
+]
 
-A[.., 2] = [3 2 6 5
-    3 2 6 6]
+A[.., 2] = [
+    3 2 6 5
+    3 2 6 6
+]
 
-@test A[:, :, 1] == [2 1 4 5
-    2 2 3 6]
+@test A[:, :, 1] == [
+    2 1 4 5
+    2 2 3 6
+]
 
-@test A[:, :, 2] == [3 2 6 5
-    3 2 6 6]
+@test A[:, :, 2] == [
+    3 2 6 5
+    3 2 6 6
+]
 
-@test A[:, .., 1] == [2 1 4 5
-    2 2 3 6]
+@test A[:, .., 1] == [
+    2 1 4 5
+    2 2 3 6
+]
 
-@test A[:, .., 1] == [2 1 4 5
-    2 2 3 6]
+@test A[:, .., 1] == [
+    2 1 4 5
+    2 2 3 6
+]
 
-A[1, ..] = reshape([3 4
+A[1, ..] = reshape(
+    [
+        3 4
         5 6
         4 5
-        6 7],
-    1,
+        6 7
+    ],
     4,
-    2)
+    2
+)
 
-B = [3 4
+B = [
+    3 4
     5 6
     4 5
-    6 7]
+    6 7
+]
 
 @test B == reshape(A[1, ..], 4, 2) == reshape(view(A, 1, ..), 4, 2)
 
@@ -77,16 +97,18 @@ C[1, 1] += 1
     @test StaticArrayInterface.getindex(A, :, .., 1) == [2 1 4 5; 2 2 3 6]
     @test StaticArrayInterface.getindex(A, :, .., 2) == [3 2 6 5; 3 2 6 6]
 
-    StaticArrayInterface.setindex!(A, reshape([3 4; 5 6; 4 5; 6 7], 1, 4, 2), 1, ..)
+    StaticArrayInterface.setindex!(A, reshape([3 4; 5 6; 4 5; 6 7], 4, 2), 1, ..)
 
-    B = [3 4
+    B = [
+        3 4
         5 6
         4 5
-        6 7]
+        6 7
+    ]
 
     @test B ==
-          reshape(StaticArrayInterface.getindex(A, 1, ..), 4, 2) ==
-          reshape(view(A, 1, ..), 4, 2)
+        reshape(StaticArrayInterface.getindex(A, 1, ..), 4, 2) ==
+        reshape(view(A, 1, ..), 4, 2)
 
     @test A[:, 1, 2] == StaticArrayInterface.getindex(A, .., 1, 2)
 
