@@ -1,3 +1,5 @@
+using Test
+using EllipsisNotation
 @testset "CartesianIndex" begin
     A = rand(4, 4, 4, 4, 4)
     @test A[.., 1, 2, 3] == A[.., CartesianIndex(1, 2, 3)]
