@@ -1,3 +1,5 @@
+using Test
+using EllipsisNotation
 B = Array{Int}(undef, 2, 3, 4, 5, 6)
 
 n = 0
